@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009-2011 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2012 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -208,12 +208,10 @@ gcm_viewer_profile_get_sort_string (CdProfile *profile)
 		sort[1] = '1';
 	else if (g_strcmp0 (id, CD_PROFILE_METADATA_DATA_SOURCE_EDID) == 0)
 		sort[1] = '2';
-#if CD_CHECK_VERSION(0,1,14)
 	else if (g_strcmp0 (id, CD_PROFILE_METADATA_DATA_SOURCE_STANDARD) == 0)
 		sort[1] = '3';
 	else if (g_strcmp0 (id, CD_PROFILE_METADATA_DATA_SOURCE_TEST) == 0)
 		sort[1] = '4';
-#endif
 	else
 		sort[1] = '0';
 
@@ -253,11 +251,9 @@ gcm_viewer_update_profile_connect_cb (GObject *source_object,
 		goto out;
 	}
 
-#if CD_CHECK_VERSION(0,1,13)
 	/* ignore profiles from other user accounts */
 	if (!cd_profile_has_access (profile))
 		goto out;
-#endif
 
 	profile_kind = cd_profile_get_kind (profile);
 	icon_name = gcm_viewer_profile_kind_to_icon_name (profile_kind);
@@ -802,6 +798,8 @@ struct {
 	{ CD_PROFILE_METADATA_SCREEN_SURFACE,		N_("Screen surface finish") },
 	/* TRANSLATORS: e.g. DVI or VGA */
 	{ CD_PROFILE_METADATA_CONNECTION_TYPE,		N_("Connection type") },
+	/* TRANSLATORS: e.g. Screen brightness in percent */
+	{ CD_PROFILE_METADATA_SCREEN_BRIGHTNESS,	N_("Screen brightness") },
 	{ NULL, NULL }
 };
 
@@ -901,6 +899,62 @@ out:
 	return ret;
 }
 
+/**
+ * gcm_profile_warning_to_string:
+ **/
+static const gchar *
+gcm_profile_warning_to_string (CdProfileWarning kind_enum)
+{
+	const gchar *kind = NULL;
+	switch (kind_enum) {
+	case CD_PROFILE_WARNING_DESCRIPTION_MISSING:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("No description has been set");
+		break;
+	case CD_PROFILE_WARNING_COPYRIGHT_MISSING:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("No copyright has been set");
+		break;
+	case CD_PROFILE_WARNING_VCGT_NON_MONOTONIC:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The display compensation table is invalid");
+		break;
+	case CD_PROFILE_WARNING_SCUM_DOT:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("A scum dot is present for media white");
+		break;
+	case CD_PROFILE_WARNING_GRAY_AXIS_INVALID:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The gray axis contains significant amounts of color");
+		break;
+	case CD_PROFILE_WARNING_GRAY_AXIS_NON_MONOTONIC:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The gray axis is non-monotonic");
+		break;
+	case CD_PROFILE_WARNING_PRIMARIES_INVALID:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("One or more of the primaries are invalid");
+		break;
+	case CD_PROFILE_WARNING_PRIMARIES_NON_ADDITIVE:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The primaries do not add to white");
+		break;
+	case CD_PROFILE_WARNING_PRIMARIES_UNLIKELY:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("One or more of the primaries is unlikely");
+		break;
+	case CD_PROFILE_WARNING_WHITEPOINT_INVALID:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The white is not D50 white");
+		break;
+	default:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("Unknown warning type");
+		break;
+	}
+	return kind;
+}
+
 /**
  * gcm_viewer_set_profile:
  **/
@@ -933,6 +987,10 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	guint filesize;
 	gboolean show_section = FALSE;
 	GError *error = NULL;
+	gchar **warnings;
+	guint i;
+	CdProfileWarning warning;
+	GString *str;
 
 	/* connect to the profile */
 	ret = cd_profile_connect_sync (profile, NULL, &error);
@@ -1074,6 +1132,31 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	gtk_label_set_label (GTK_LABEL (widget), temp);
 	g_free (temp);
 
+	/* set warnings */
+	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "hbox_warnings"));
+	warnings = cd_profile_get_warnings (profile);
+	size = g_strv_length (warnings);
+	if (size == 0) {
+		gtk_widget_set_visible (widget, FALSE);
+	} else {
+		gtk_widget_set_visible (widget, TRUE);
+		widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_warnings"));
+		str = g_string_new ("");
+		/* TRANSLATORS: profiles that have warnings are useable,
+		 * but may not be any good */
+		g_string_append_printf (str, "%s\n", _("The profile has the following problems:"));
+		for (i = 0; i < size; i++) {
+			g_debug ("warnings[i]=%s", warnings[i]);
+			warning = cd_profile_warning_from_string (warnings[i]);
+			g_string_append_printf (str, "• %s\n",
+						gcm_profile_warning_to_string (warning));
+		}
+		if (str->len > 0)
+			g_string_set_size (str, str->len - 1);
+		gtk_label_set_label (GTK_LABEL (widget), str->str);
+		g_string_free (str, TRUE);
+	}
+
 	/* set profile version */
 	filename = gcm_profile_get_version (gcm_profile);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
@@ -1667,6 +1750,10 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 						     "label_title_filename"));
 	context = gtk_widget_get_style_context (widget);
 	gtk_style_context_add_class (context, "dim-label");
+	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
+						     "label_title_warnings"));
+	context = gtk_widget_get_style_context (widget);
+	gtk_style_context_add_class (context, "dim-label");
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
 						     "label_title_version"));
 	context = gtk_widget_get_style_context (widget);
